pub enum EntryKind {
File,
Directory,
Symlink,
NamedPipe,
Socket,
CharDevice,
BlockDevice,
Hardlink,
Unknown(char),
}Expand description
The kind of filesystem object a catalog entry describes.
Variants
File
Directory
Symlink
NamedPipe
Socket
CharDevice
BlockDevice
Hardlink
Unknown(char)
A catalog entry type this reader does not model (the raw cat_sig letter).